import {Component, Input, OnInit} from '@angular/core';
import {Transition} from "../../../../game-model/gamesystems/transitions/Transition";
import {MatTableDataSource} from "@angular/material/table";
import {ScriptAccountAction} from "../../../../game-model/gamesystems/actions/ScriptAccountAction";
import {ScriptAccount} from "../../../../game-model/scriptAccounts/ScriptAccount";

@Component({
  selector: 'app-scriptaccount-action-editor',
  templateUrl: './scriptaccount-action-editor.component.html',
  styleUrl: './scriptaccount-action-editor.component.scss'
})
export class ScriptaccountActionEditorComponent  implements OnInit{
  @Input() transition: Transition<any> | undefined
  @Input() scriptAccounts: ScriptAccount[] = []
  @Input() enableEditing: boolean = false;

  dataSource: MatTableDataSource<ScriptAccountAction> = new MatTableDataSource();
  displayedColumns: string[] = ['scriptAccount', "valueChange", 'edit', 'delete'];

  editedAction: ScriptAccountAction | undefined
  addedAction: ScriptAccountAction | undefined

  ngOnInit() {
    this.dataSource.data = this.transition!.scriptAccountActions.map(action => action);

    if(!this.enableEditing) {
      this.displayedColumns = this.displayedColumns.slice(0, -2);
    }
  }

  editAction(scriptAccountAction: ScriptAccountAction) {
    this.editedAction = scriptAccountAction;
  }

  createNewAction() {
    this.addedAction = new ScriptAccountAction(new ScriptAccount("", ""), 0);
    this.editedAction = this.addedAction;

    this.dataSource.data = this.dataSource.data.concat(this.addedAction);
  }

  finishEditing() {
    if(this.addedAction != undefined && this.addedAction.scriptAccount.componentName !== '') {
      this.transition?.addScriptAccountAction(this.addedAction)
      console.log(this.addedAction.scriptAccount)
      this.dataSource.data = this.transition!.scriptAccountActions;
      console.log(this.dataSource.data.length, this.transition!.scriptAccountActions.length)
      this.addedAction = undefined;
    }
    this.editedAction = undefined;
  }

  deleteAction(action: ScriptAccountAction) {
    this.transition!.removeScriptAccountAction(action.scriptAccount)
    this.dataSource.data = this.transition!.scriptAccountActions
  }
}
